﻿using System.Collections.Generic;
using NUnit.Framework;

namespace Josso.Agent.Lib.Tests
{
    [TestFixture]
    public class ZjsJossoTests
    {
        private const string GATEWAY = "https://auth.dev.local";

        private const string USER = "webtest_admin@virtuoz.com";

        private const string PWD = "#######";

        private readonly ZjsJosso _josso;

        public ZjsJossoTests()
        {
            _josso = new ZjsJosso(GATEWAY);
        }

        /// <summary>
        /// Identify the user.
        /// </summary>
        [Test, Category("BIG")]
        public void TestIdentifyUser()
        {
            string session;
            bool identified = _josso.IdentifyUser(USER, PWD, out session);
            Assert.IsTrue(identified);
        }

        /// <summary>
        /// Test to get the user name.
        /// </summary>
        [Test, Category("BIG")]
        public void TestGetUserName()
        {
            string user = _josso.GetUserName(getSession());
            Assert.AreEqual(USER, user);
        }

        /// <summary>
        /// Test the global logout
        /// </summary>
        [Test, Category("BIG")]
        public void TestGlobalLogout()
        {
            string session = getSession();
            _josso.GlobalLogout(session);
            Assert.IsFalse(_josso.AccessSession(session));
        }

        /// <summary>
        /// Test the access session functionality
        /// </summary>
        [Test, Category("BIG")]
        public void TestAccessSession()
        {
            Assert.IsTrue(_josso.AccessSession(getSession()));
        }

        /// <summary>
        /// Test the access session functionality
        /// </summary>
        [Test, Category("BIG")]
        public void TestGetProperties()
        {
            Dictionary<string, string> properties = _josso.GetProperties(getSession());
            Assert.GreaterOrEqual(properties.Count, 1, "There should be at least 1 properties");
            Assert.Contains("josso.user.dn", properties.Keys);
            Assert.AreEqual("uid=webtest_admin@virtuoz.com,ou=fulltime,ou=employees,dc=ds,dc=virtuoz,dc=com",
                            properties["josso.user.dn"]);
        }

        /// <summary>
        /// Resolve a wrong assertion
        /// </summary>
        [Test, Category("BIG")]
        public void TestResolveWrongAuthenticationAssertion()
        {
            string session;
            bool result = _josso.ResolveAuthenticationAssertion("wrong assertion", out session);
            Assert.IsFalse(result);
            Assert.IsNull(session);
        }

        /// <summary>
        /// Return an active session.
        /// </summary>
        /// <returns>An active sso session token.</returns>
        private string getSession()
        {
            string session;
            _josso.IdentifyUser(USER, PWD, out session);
            return session;
        }
    }
}