﻿using System.Collections.Generic;
using System.Web;
using NUnit.Framework;

namespace Josso.Agent.Lib.Tests
{
    [TestFixture]
    public class ZjsUserTests
    {
        private readonly ZjsAgent _agent;

        public ZjsUserTests()
        {
            _agent = ZjsAgent.Init(ZjsAgentTests.FAKE_GATEWAY, "login", "logout", "check", false);
        }

        [SetUp]
        public void Setup()
        {
            _agent.Josso = new ZjsAgentTests.ZjsMockedJosso();
        }

        /// <summary>
        /// Get the current user properties
        /// </summary>
        [Test, Category("SMALL")]
        public void TestGetCurrentUserProperties()
        {
            Dictionary<string, string> properties = new Dictionary<string, string>
            {
                { "propery1", "property_value"},
                { "propery2", "property_value"}
            };

            ZjsUser user = getUser(properties);

            Assert.IsNotNull(user);
            Assert.AreEqual(properties, user.Properties);
        }

        /// <summary>
        /// Get the user when you mock josso with the specific properties.
        /// </summary>
        /// <param name="properties"></param>
        /// <returns>The user</returns>
        private ZjsUser getUser(Dictionary<string, string> properties)
        {
            HttpRequestBase request = ZjsAgentTests.GetMockedRequest();
            request.Cookies.Add(new HttpCookie(
                                    ZjsBaseAgent.COOKIE_NAME,
                                    ZjsAgentTests.ZjsMockedJosso.SSO_SESSION));
            ((ZjsAgentTests.ZjsMockedJosso)_agent.Josso).UserName = ZjsAgentTests.USERNAME;
            ((ZjsAgentTests.ZjsMockedJosso)_agent.Josso).Properties = properties;

            _agent.JossoInvalidateCurrentUser(request);
            return _agent.JossoCurrentUser(request);
        }
    }
}