﻿using System.Web;

namespace Josso.Agent.Lib
{
    /// <summary>
    /// This is an interface for the josso agent. This is specially useful for the test
    /// </summary>
    public interface YjsAgent
    {
        /// <summary>
        /// The action in the controller when a user log
        /// </summary>
        /// <param name="request"></param>
        /// <param name="session"></param>
        string GetJossoLoginPage(HttpRequestBase request, HttpSessionStateBase session);

        /// <summary>
        /// The action in the controller when a user logout
        /// </summary>
        /// <param name="request"></param>
        /// <param name="response"></param>
        void JossoLogoutPageAction(HttpRequestBase request, HttpResponseBase response);

        /// <summary>
        /// The action to check the user assertion
        /// </summary>
        /// <param name="request"></param>
        /// <param name="session"></param>
        /// <param name="response"></param>
        void JossoCheckPageAction(HttpRequestBase request, HttpSessionStateBase session,
                                  HttpResponseBase response);

        /// <summary>
        /// Create a logout URL that redirect then to the specific url.
        /// </summary>
        /// <param name="request">the current request object.</param>
        /// <param name="url">The specific url to redirect after the logout.</param>
        /// <returns>The url</returns>
        string JossoCreateLogoutUrl(HttpRequestBase request, string url);

        /// <summary>
        /// This function returns the current SSO user, if no user has been authenticated or if
        /// the SSO Session has expired, it returns null
        /// </summary>
        /// <param name="request"></param>
        /// <returns>the current user</returns>
        ZjsUser JossoCurrentUser(HttpRequestBase request);

        /// <summary>
        /// Tells Josso to forget cached information about the current user.
        /// </summary>
        /// <param name="request">The user request.</param>
        void JossoInvalidateCurrentUser(HttpRequestBase request);

        /// <summary>
        /// Use this function when ever you want to start user authentication.
        /// This function tries to fill the username if logged in. It also provides
        /// a redirect url that the caller should use.
        /// </summary>
        /// <param name="request"></param>
        /// <param name="session"></param>
        /// <param name="jossoLogin"></param>
        /// <param name="redirectUrl"></param>
        /// <returns>Returns true if the user is logged AND his password is still valid (not expired)</returns>
        bool TryGetJossoLogin(HttpRequestBase request, HttpSessionStateBase session, out string jossoLogin, out string redirectUrl);

        /// <summary>
        /// Creates a logout url for the current page, use to create links to JOSSO logout page
        /// </summary>
        /// <param name="request"></param>
        /// <returns>the url</returns>
        string JossoCreateLogoutUrl(HttpRequestBase request);

        /// <summary>
        /// Creates a login url for the current page, use to create links to JOSSO login page
        /// </summary>
        /// <param name="request"></param>
        /// <returns>the url</returns>
        string JossoCreateLoginUrl(HttpRequestBase request);

        /// <summary>
        /// the url of the info of the user (on the josso server)
        /// </summary>
        string JossoInfoUrl { get; }
    }
}