﻿using System;
using System.Net;

namespace Josso.Agent.Lib
{
    /// <summary>
    /// Authenticate WinForm applications or Web Application with Josso.
    /// </summary>
    public class ZjsApplicationAgent : ZjsBaseAgent
    {
        /// <summary>
        /// The josso cookie used for the requests
        /// </summary>
        private Cookie _jossoCookie;

        /// <summary>
        /// Constructor with the address of the josso proxy
        /// </summary>
        /// <param name="gatewayUrl">The josso Url. Ex: https://login.virtuoz.com</param>
        public ZjsApplicationAgent(string gatewayUrl) : base(gatewayUrl) { }

        /// <summary>
        /// Constructor with the address of the josso proxy and a specific
        /// boolean that tell to use ssl or not.
        /// </summary>
        /// <param name="gatewayUrl">The josso url.</param>
        /// <param name="disableSSL">True means no certificate validation.</param>
        public ZjsApplicationAgent(string gatewayUrl, bool disableSSL)
            : base(gatewayUrl, disableSSL) { }

        /// <summary>
        /// Identify a user against Josso.
        /// </summary>
        /// <param name="user">the user name</param>
        /// <param name="password">the password</param>
        /// <param name="session">the josso session created for the user</param>
        /// <returns>true if the user has been authentified, false otherwise</returns>
        public bool IdentifyUser(string user, string password, out string session)
        {
            return Josso.IdentifyUser(user, password, out session);
        }

        /// <summary>
        /// Create an authentified HttpWebRequest to a josso-protected Url, ready to be used.
        /// </summary>
        /// <param name="url">The josso-protected Url to query</param>
        /// <param name="user">The user name used</param>
        /// <param name="password">The password of the user name</param>
        /// <returns>
        /// The HttpWebRequest with the josso cookie set.
        /// Null if the user authentification failed.
        /// </returns>
        public HttpWebRequest CreateWebRequest(Uri url, string user, string password)
        {
            if (null == _jossoCookie || _jossoCookie.Expired)
            {
                string session;
                if (!Josso.IdentifyUser(user, password, out session))
                    return null;
                _jossoCookie = new Cookie(COOKIE_NAME, session) { Domain = url.Host };
            }

            HttpWebRequest request = (HttpWebRequest)WebRequest.Create(url);
            CookieContainer cookieContainer = new CookieContainer();
            cookieContainer.Add(_jossoCookie);
            request.CookieContainer = cookieContainer;
            return request;
        }

        /// <summary>
        /// Resets JOSSO authentication
        /// </summary>
        public void ResetCookie()
        {
            _jossoCookie = null;
        }
    }
}